| Title: | Functions to Be Used in Life Cycle Assessment (LCA) Projects |
|---|---|
| Description: | This package contains a function to read LCA. parameters from an Excel file that was sent to and received from a project partner. The parameters are read into a data frame. Another function can be used to write the dataframe into an Excel file with different sheets and data. |
| Authors: | Hauke Sonnenberg [aut, cre] (ORCID: <https://orcid.org/0000-0001-9134-2871>), Michael Rustler [ctb] (ORCID: <https://orcid.org/0000-0003-0647-7726>), Kompetenzzentrum Wasser Berlin gGmbH (KWB) [cph] |
| Maintainer: | Hauke Sonnenberg <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-15 06:29:25 UTC |
| Source: | https://github.com/KWB-R/kwb.lca |
Read LCA Parameters from an Excel File
read_lca_parameters_from_xls(file, country = "de")read_lca_parameters_from_xls(file, country = "de")
file |
path to the Excel file to be read |
country |
country code: "de" for German or "en" for "English". Required to convert the text values in the Value columns |
Save LCA parameters to an Excel File
save_lca_parameters_to_xlsx(lca, file, overwrite = FALSE)save_lca_parameters_to_xlsx(lca, file, overwrite = FALSE)
lca |
data frame with lca parameters as returned by
|
file |
path to Excel file to be written |
overwrite |
it |